@@ -6,8 +6,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_CONTACTGROUPMODEL_P_H
-#define AKONADI_CONTACTGROUPMODEL_P_H
+#pragma once
 
 #include <QAbstractItemModel>
 
@@ -47,4 +46,3 @@ private:
 };
 }
 
-#endif
