@@ -6,8 +6,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_CONTACTGROUPVIEWERDIALOG_H
-#define AKONADI_CONTACTGROUPVIEWERDIALOG_H
+#pragma once
 
 #include "akonadi-contact_export.h"
 
@@ -83,4 +82,3 @@ private:
 };
 }
 
-#endif
