@@ -123,11 +123,11 @@ public:
         QVector<QVariantMap> customFieldDescriptions;
         const CustomField::List globalCustomFields = CustomFieldManager::globalCustomFieldDescriptions();
         customFieldDescriptions.reserve(localCustomFieldDescriptions.count() + globalCustomFields.count());
-        for (const QVariant &entry : qAsConst(localCustomFieldDescriptions)) {
+        for (const QVariant &entry : std::as_const(localCustomFieldDescriptions)) {
             customFieldDescriptions << entry.toMap();
         }
 
-        for (const CustomField &field : qAsConst(globalCustomFields)) {
+        for (const CustomField &field : std::as_const(globalCustomFields)) {
             QVariantMap description;
             description.insert(QStringLiteral("key"), field.key());
             description.insert(QStringLiteral("title"), field.title());
@@ -190,7 +190,7 @@ public:
         QString addressBookName;
 
         if (!job->error()) {
-            auto *fetchJob = qobject_cast<CollectionFetchJob *>(job);
+            auto fetchJob = qobject_cast<CollectionFetchJob *>(job);
             if (!fetchJob->collections().isEmpty()) {
                 const Collection collection = fetchJob->collections().at(0);
                 addressBookName = collection.displayName();
@@ -220,7 +220,7 @@ ContactViewer::ContactViewer(QWidget *parent)
     : QWidget(parent)
     , d(new Private(this))
 {
-    auto *layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
 
     d->mBrowser = new TextBrowser;
