@@ -6,10 +6,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef CATEGORIESEDITWIDGET_H
-#define CATEGORIESEDITWIDGET_H
-
-#include <QWidget>
+#pragma once
 
 #include <kcontacts/addressee.h>
 
@@ -32,4 +29,3 @@ public:
     void setReadOnly(bool readOnly) override;
 };
 
-#endif
